# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NetworkSources(object):
    """
    A network source specifies a list of source IP addresses that are allowed to make authorization requests.
    Use the network source in policy statements to restrict access to only requests that come from the specified IPs.
    For more information, see `Managing Network Sources`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Tasks/managingnetworksources.htm
    """

    #: A constant which can be used with the lifecycle_state property of a NetworkSources.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a NetworkSources.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a NetworkSources.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a NetworkSources.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a NetworkSources.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new NetworkSources object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this NetworkSources.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this NetworkSources.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this NetworkSources.
        :type name: str

        :param description:
            The value to assign to the description property of this NetworkSources.
        :type description: str

        :param public_source_list:
            The value to assign to the public_source_list property of this NetworkSources.
        :type public_source_list: list[str]

        :param virtual_source_list:
            The value to assign to the virtual_source_list property of this NetworkSources.
        :type virtual_source_list: list[oci.identity.models.NetworkSourcesVirtualSourceList]

        :param services:
            The value to assign to the services property of this NetworkSources.
        :type services: list[str]

        :param time_created:
            The value to assign to the time_created property of this NetworkSources.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this NetworkSources.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param inactive_status:
            The value to assign to the inactive_status property of this NetworkSources.
        :type inactive_status: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this NetworkSources.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this NetworkSources.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'name': 'str',
            'description': 'str',
            'public_source_list': 'list[str]',
            'virtual_source_list': 'list[NetworkSourcesVirtualSourceList]',
            'services': 'list[str]',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'inactive_status': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'name': 'name',
            'description': 'description',
            'public_source_list': 'publicSourceList',
            'virtual_source_list': 'virtualSourceList',
            'services': 'services',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'inactive_status': 'inactiveStatus',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._name = None
        self._description = None
        self._public_source_list = None
        self._virtual_source_list = None
        self._services = None
        self._time_created = None
        self._lifecycle_state = None
        self._inactive_status = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this NetworkSources.
        The OCID of the network source.


        :return: The id of this NetworkSources.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NetworkSources.
        The OCID of the network source.


        :param id: The id of this NetworkSources.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this NetworkSources.
        The OCID of the tenancy containing the network source. The tenancy is the root compartment.


        :return: The compartment_id of this NetworkSources.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this NetworkSources.
        The OCID of the tenancy containing the network source. The tenancy is the root compartment.


        :param compartment_id: The compartment_id of this NetworkSources.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this NetworkSources.
        The name you assign to the network source during creation. The name must be unique across
        the tenancy and cannot be changed.


        :return: The name of this NetworkSources.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NetworkSources.
        The name you assign to the network source during creation. The name must be unique across
        the tenancy and cannot be changed.


        :param name: The name of this NetworkSources.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this NetworkSources.
        The description you assign to the network source. Does not have to be unique, and it's changeable.


        :return: The description of this NetworkSources.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this NetworkSources.
        The description you assign to the network source. Does not have to be unique, and it's changeable.


        :param description: The description of this NetworkSources.
        :type: str
        """
        self._description = description

    @property
    def public_source_list(self):
        """
        Gets the public_source_list of this NetworkSources.
        A list of allowed public IPs and CIDR ranges.


        :return: The public_source_list of this NetworkSources.
        :rtype: list[str]
        """
        return self._public_source_list

    @public_source_list.setter
    def public_source_list(self, public_source_list):
        """
        Sets the public_source_list of this NetworkSources.
        A list of allowed public IPs and CIDR ranges.


        :param public_source_list: The public_source_list of this NetworkSources.
        :type: list[str]
        """
        self._public_source_list = public_source_list

    @property
    def virtual_source_list(self):
        """
        Gets the virtual_source_list of this NetworkSources.
        A list of allowed VCN OCID and IP range pairs.
        Example:`\"vcnId\": \"ocid1.vcn.oc1.iad.aaaaaaaaexampleuniqueID\", \"ipRanges\": [ \"129.213.39.0/24\" ]`


        :return: The virtual_source_list of this NetworkSources.
        :rtype: list[oci.identity.models.NetworkSourcesVirtualSourceList]
        """
        return self._virtual_source_list

    @virtual_source_list.setter
    def virtual_source_list(self, virtual_source_list):
        """
        Sets the virtual_source_list of this NetworkSources.
        A list of allowed VCN OCID and IP range pairs.
        Example:`\"vcnId\": \"ocid1.vcn.oc1.iad.aaaaaaaaexampleuniqueID\", \"ipRanges\": [ \"129.213.39.0/24\" ]`


        :param virtual_source_list: The virtual_source_list of this NetworkSources.
        :type: list[oci.identity.models.NetworkSourcesVirtualSourceList]
        """
        self._virtual_source_list = virtual_source_list

    @property
    def services(self):
        """
        Gets the services of this NetworkSources.
        A list of services allowed to make on-behalf-of requests. These requests can have different source IPs than
        those specified in the network source.
        Currently, only `all` and `none` are supported. The default is `all`.


        :return: The services of this NetworkSources.
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """
        Sets the services of this NetworkSources.
        A list of services allowed to make on-behalf-of requests. These requests can have different source IPs than
        those specified in the network source.
        Currently, only `all` and `none` are supported. The default is `all`.


        :param services: The services of this NetworkSources.
        :type: list[str]
        """
        self._services = services

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this NetworkSources.
        Date and time the group was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this NetworkSources.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this NetworkSources.
        Date and time the group was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this NetworkSources.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this NetworkSources.
        The network source object's current state. After creating a network source, make sure its `lifecycleState` changes from CREATING to
        ACTIVE before using it.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this NetworkSources.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this NetworkSources.
        The network source object's current state. After creating a network source, make sure its `lifecycleState` changes from CREATING to
        ACTIVE before using it.


        :param lifecycle_state: The lifecycle_state of this NetworkSources.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def inactive_status(self):
        """
        Gets the inactive_status of this NetworkSources.
        The detailed status of INACTIVE lifecycleState.


        :return: The inactive_status of this NetworkSources.
        :rtype: int
        """
        return self._inactive_status

    @inactive_status.setter
    def inactive_status(self, inactive_status):
        """
        Sets the inactive_status of this NetworkSources.
        The detailed status of INACTIVE lifecycleState.


        :param inactive_status: The inactive_status of this NetworkSources.
        :type: int
        """
        self._inactive_status = inactive_status

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this NetworkSources.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this NetworkSources.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this NetworkSources.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this NetworkSources.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this NetworkSources.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this NetworkSources.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this NetworkSources.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this NetworkSources.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceAvailability(object):
    """
    The availability of a given resource limit, based on the usage, tenant service limits, and quotas set for the tenancy.
    Note: We cannot guarantee this data for all the limits. In such cases, these fields will be empty.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceAvailability object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param used:
            The value to assign to the used property of this ResourceAvailability.
        :type used: int

        :param available:
            The value to assign to the available property of this ResourceAvailability.
        :type available: int

        :param fractional_usage:
            The value to assign to the fractional_usage property of this ResourceAvailability.
        :type fractional_usage: float

        :param fractional_availability:
            The value to assign to the fractional_availability property of this ResourceAvailability.
        :type fractional_availability: float

        :param effective_quota_value:
            The value to assign to the effective_quota_value property of this ResourceAvailability.
        :type effective_quota_value: float

        """
        self.swagger_types = {
            'used': 'int',
            'available': 'int',
            'fractional_usage': 'float',
            'fractional_availability': 'float',
            'effective_quota_value': 'float'
        }

        self.attribute_map = {
            'used': 'used',
            'available': 'available',
            'fractional_usage': 'fractionalUsage',
            'fractional_availability': 'fractionalAvailability',
            'effective_quota_value': 'effectiveQuotaValue'
        }

        self._used = None
        self._available = None
        self._fractional_usage = None
        self._fractional_availability = None
        self._effective_quota_value = None

    @property
    def used(self):
        """
        Gets the used of this ResourceAvailability.
        The current usage in the given compartment. To support resources with fractional counts,
        the field rounds up to the nearest integer.


        :return: The used of this ResourceAvailability.
        :rtype: int
        """
        return self._used

    @used.setter
    def used(self, used):
        """
        Sets the used of this ResourceAvailability.
        The current usage in the given compartment. To support resources with fractional counts,
        the field rounds up to the nearest integer.


        :param used: The used of this ResourceAvailability.
        :type: int
        """
        self._used = used

    @property
    def available(self):
        """
        Gets the available of this ResourceAvailability.
        The count of available resources. To support resources with fractional counts,
        the field rounds down to the nearest integer.


        :return: The available of this ResourceAvailability.
        :rtype: int
        """
        return self._available

    @available.setter
    def available(self, available):
        """
        Sets the available of this ResourceAvailability.
        The count of available resources. To support resources with fractional counts,
        the field rounds down to the nearest integer.


        :param available: The available of this ResourceAvailability.
        :type: int
        """
        self._available = available

    @property
    def fractional_usage(self):
        """
        Gets the fractional_usage of this ResourceAvailability.
        The current most accurate usage in the given compartment.


        :return: The fractional_usage of this ResourceAvailability.
        :rtype: float
        """
        return self._fractional_usage

    @fractional_usage.setter
    def fractional_usage(self, fractional_usage):
        """
        Sets the fractional_usage of this ResourceAvailability.
        The current most accurate usage in the given compartment.


        :param fractional_usage: The fractional_usage of this ResourceAvailability.
        :type: float
        """
        self._fractional_usage = fractional_usage

    @property
    def fractional_availability(self):
        """
        Gets the fractional_availability of this ResourceAvailability.
        The most accurate count of available resources.


        :return: The fractional_availability of this ResourceAvailability.
        :rtype: float
        """
        return self._fractional_availability

    @fractional_availability.setter
    def fractional_availability(self, fractional_availability):
        """
        Sets the fractional_availability of this ResourceAvailability.
        The most accurate count of available resources.


        :param fractional_availability: The fractional_availability of this ResourceAvailability.
        :type: float
        """
        self._fractional_availability = fractional_availability

    @property
    def effective_quota_value(self):
        """
        Gets the effective_quota_value of this ResourceAvailability.
        The effective quota value for the given compartment. This field is only present if there is a
        current quota policy affecting the current resource in the target region or availability domain.


        :return: The effective_quota_value of this ResourceAvailability.
        :rtype: float
        """
        return self._effective_quota_value

    @effective_quota_value.setter
    def effective_quota_value(self, effective_quota_value):
        """
        Sets the effective_quota_value of this ResourceAvailability.
        The effective quota value for the given compartment. This field is only present if there is a
        current quota policy affecting the current resource in the target region or availability domain.


        :param effective_quota_value: The effective_quota_value of this ResourceAvailability.
        :type: float
        """
        self._effective_quota_value = effective_quota_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDatabaseRegistrationDetails(object):
    """
    The information about a new DatabaseRegistration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDatabaseRegistrationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateDatabaseRegistrationDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateDatabaseRegistrationDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDatabaseRegistrationDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDatabaseRegistrationDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDatabaseRegistrationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param fqdn:
            The value to assign to the fqdn property of this CreateDatabaseRegistrationDetails.
        :type fqdn: str

        :param ip_address:
            The value to assign to the ip_address property of this CreateDatabaseRegistrationDetails.
        :type ip_address: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateDatabaseRegistrationDetails.
        :type subnet_id: str

        :param database_id:
            The value to assign to the database_id property of this CreateDatabaseRegistrationDetails.
        :type database_id: str

        :param username:
            The value to assign to the username property of this CreateDatabaseRegistrationDetails.
        :type username: str

        :param password:
            The value to assign to the password property of this CreateDatabaseRegistrationDetails.
        :type password: str

        :param connection_string:
            The value to assign to the connection_string property of this CreateDatabaseRegistrationDetails.
        :type connection_string: str

        :param wallet:
            The value to assign to the wallet property of this CreateDatabaseRegistrationDetails.
        :type wallet: str

        :param alias_name:
            The value to assign to the alias_name property of this CreateDatabaseRegistrationDetails.
        :type alias_name: str

        :param vault_id:
            The value to assign to the vault_id property of this CreateDatabaseRegistrationDetails.
        :type vault_id: str

        :param key_id:
            The value to assign to the key_id property of this CreateDatabaseRegistrationDetails.
        :type key_id: str

        :param secret_compartment_id:
            The value to assign to the secret_compartment_id property of this CreateDatabaseRegistrationDetails.
        :type secret_compartment_id: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'fqdn': 'str',
            'ip_address': 'str',
            'subnet_id': 'str',
            'database_id': 'str',
            'username': 'str',
            'password': 'str',
            'connection_string': 'str',
            'wallet': 'str',
            'alias_name': 'str',
            'vault_id': 'str',
            'key_id': 'str',
            'secret_compartment_id': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'fqdn': 'fqdn',
            'ip_address': 'ipAddress',
            'subnet_id': 'subnetId',
            'database_id': 'databaseId',
            'username': 'username',
            'password': 'password',
            'connection_string': 'connectionString',
            'wallet': 'wallet',
            'alias_name': 'aliasName',
            'vault_id': 'vaultId',
            'key_id': 'keyId',
            'secret_compartment_id': 'secretCompartmentId'
        }

        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._fqdn = None
        self._ip_address = None
        self._subnet_id = None
        self._database_id = None
        self._username = None
        self._password = None
        self._connection_string = None
        self._wallet = None
        self._alias_name = None
        self._vault_id = None
        self._key_id = None
        self._secret_compartment_id = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateDatabaseRegistrationDetails.
        An object's Display Name.


        :return: The display_name of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDatabaseRegistrationDetails.
        An object's Display Name.


        :param display_name: The display_name of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateDatabaseRegistrationDetails.
        Metadata about this specific object.


        :return: The description of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDatabaseRegistrationDetails.
        Metadata about this specific object.


        :param description: The description of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDatabaseRegistrationDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateDatabaseRegistrationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDatabaseRegistrationDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateDatabaseRegistrationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDatabaseRegistrationDetails.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateDatabaseRegistrationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDatabaseRegistrationDetails.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateDatabaseRegistrationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def fqdn(self):
        """
        **[Required]** Gets the fqdn of this CreateDatabaseRegistrationDetails.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :return: The fqdn of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._fqdn

    @fqdn.setter
    def fqdn(self, fqdn):
        """
        Sets the fqdn of this CreateDatabaseRegistrationDetails.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :param fqdn: The fqdn of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._fqdn = fqdn

    @property
    def ip_address(self):
        """
        Gets the ip_address of this CreateDatabaseRegistrationDetails.
        The private IP address in the customer's VCN of the customer's endpoint, typically a database.


        :return: The ip_address of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this CreateDatabaseRegistrationDetails.
        The private IP address in the customer's VCN of the customer's endpoint, typically a database.


        :param ip_address: The ip_address of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def database_id(self):
        """
        Gets the database_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the database being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_id of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the database being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_id: The database_id of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._database_id = database_id

    @property
    def username(self):
        """
        **[Required]** Gets the username of this CreateDatabaseRegistrationDetails.
        The username Oracle GoldenGate uses to connect the associated RDBMS.  This username must already exist and be available for use by the database.  It must conform to the security requirements implemented by the database including length, case sensitivity, and so on.


        :return: The username of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this CreateDatabaseRegistrationDetails.
        The username Oracle GoldenGate uses to connect the associated RDBMS.  This username must already exist and be available for use by the database.  It must conform to the security requirements implemented by the database including length, case sensitivity, and so on.


        :param username: The username of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._username = username

    @property
    def password(self):
        """
        **[Required]** Gets the password of this CreateDatabaseRegistrationDetails.
        The password Oracle GoldenGate uses to connect the associated RDBMS.  It must conform to the specific security requirements implemented by the database including length, case sensitivity, and so on.


        :return: The password of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this CreateDatabaseRegistrationDetails.
        The password Oracle GoldenGate uses to connect the associated RDBMS.  It must conform to the specific security requirements implemented by the database including length, case sensitivity, and so on.


        :param password: The password of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._password = password

    @property
    def connection_string(self):
        """
        Gets the connection_string of this CreateDatabaseRegistrationDetails.
        Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.


        :return: The connection_string of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """
        Sets the connection_string of this CreateDatabaseRegistrationDetails.
        Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.


        :param connection_string: The connection_string of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._connection_string = connection_string

    @property
    def wallet(self):
        """
        Gets the wallet of this CreateDatabaseRegistrationDetails.
        The wallet contents Oracle GoldenGate uses to make connections to a database.  This attribute is expected to be base64 encoded.


        :return: The wallet of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._wallet

    @wallet.setter
    def wallet(self, wallet):
        """
        Sets the wallet of this CreateDatabaseRegistrationDetails.
        The wallet contents Oracle GoldenGate uses to make connections to a database.  This attribute is expected to be base64 encoded.


        :param wallet: The wallet of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._wallet = wallet

    @property
    def alias_name(self):
        """
        **[Required]** Gets the alias_name of this CreateDatabaseRegistrationDetails.
        Credential store alias.


        :return: The alias_name of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._alias_name

    @alias_name.setter
    def alias_name(self, alias_name):
        """
        Sets the alias_name of this CreateDatabaseRegistrationDetails.
        Credential store alias.


        :param alias_name: The alias_name of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._alias_name = alias_name

    @property
    def vault_id(self):
        """
        Gets the vault_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the customer vault being referenced. If provided, this will reference a vault which the customer will be required to ensure the policies are established to permit the GoldenGate Service to manage secrets contained within this vault.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vault_id of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """
        Sets the vault_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the customer vault being referenced. If provided, this will reference a vault which the customer will be required to ensure the policies are established to permit the GoldenGate Service to manage secrets contained within this vault.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vault_id: The vault_id of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._vault_id = vault_id

    @property
    def key_id(self):
        """
        Gets the key_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the customer \"Master\" key being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this key to manage secrets.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The key_id of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the customer \"Master\" key being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this key to manage secrets.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param key_id: The key_id of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._key_id = key_id

    @property
    def secret_compartment_id(self):
        """
        Gets the secret_compartment_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the compartment where the the GGS Secret will be created. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Compartment in which to create a Secret.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The secret_compartment_id of this CreateDatabaseRegistrationDetails.
        :rtype: str
        """
        return self._secret_compartment_id

    @secret_compartment_id.setter
    def secret_compartment_id(self, secret_compartment_id):
        """
        Sets the secret_compartment_id of this CreateDatabaseRegistrationDetails.
        The `OCID`__ of the compartment where the the GGS Secret will be created. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Compartment in which to create a Secret.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param secret_compartment_id: The secret_compartment_id of this CreateDatabaseRegistrationDetails.
        :type: str
        """
        self._secret_compartment_id = secret_compartment_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .absolute_wait_criteria import AbsoluteWaitCriteria
from .absolute_wait_criteria_summary import AbsoluteWaitCriteriaSummary
from .approval_action import ApprovalAction
from .approval_policy import ApprovalPolicy
from .approve_deployment_details import ApproveDeploymentDetails
from .automated_deploy_stage_rollback_policy import AutomatedDeployStageRollbackPolicy
from .backend_set_ip_collection import BackendSetIpCollection
from .cancel_deployment_details import CancelDeploymentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .compute_instance_group_blue_green_deploy_stage_execution_progress import ComputeInstanceGroupBlueGreenDeployStageExecutionProgress
from .compute_instance_group_blue_green_traffic_shift_deploy_stage_execution_progress import ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress
from .compute_instance_group_by_ids_selector import ComputeInstanceGroupByIdsSelector
from .compute_instance_group_by_query_selector import ComputeInstanceGroupByQuerySelector
from .compute_instance_group_canary_approval_deploy_stage_execution_progress import ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress
from .compute_instance_group_canary_deploy_stage_execution_progress import ComputeInstanceGroupCanaryDeployStageExecutionProgress
from .compute_instance_group_canary_traffic_shift_deploy_stage_execution_progress import ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress
from .compute_instance_group_deploy_environment import ComputeInstanceGroupDeployEnvironment
from .compute_instance_group_deploy_environment_summary import ComputeInstanceGroupDeployEnvironmentSummary
from .compute_instance_group_deploy_stage import ComputeInstanceGroupDeployStage
from .compute_instance_group_deploy_stage_execution_progress import ComputeInstanceGroupDeployStageExecutionProgress
from .compute_instance_group_deploy_stage_summary import ComputeInstanceGroupDeployStageSummary
from .compute_instance_group_failure_policy import ComputeInstanceGroupFailurePolicy
from .compute_instance_group_failure_policy_by_count import ComputeInstanceGroupFailurePolicyByCount
from .compute_instance_group_failure_policy_by_percentage import ComputeInstanceGroupFailurePolicyByPercentage
from .compute_instance_group_linear_rollout_policy_by_count import ComputeInstanceGroupLinearRolloutPolicyByCount
from .compute_instance_group_linear_rollout_policy_by_percentage import ComputeInstanceGroupLinearRolloutPolicyByPercentage
from .compute_instance_group_rollout_policy import ComputeInstanceGroupRolloutPolicy
from .compute_instance_group_selector import ComputeInstanceGroupSelector
from .compute_instance_group_selector_collection import ComputeInstanceGroupSelectorCollection
from .count_based_approval_policy import CountBasedApprovalPolicy
from .create_compute_instance_group_deploy_environment_details import CreateComputeInstanceGroupDeployEnvironmentDetails
from .create_compute_instance_group_deploy_stage_details import CreateComputeInstanceGroupDeployStageDetails
from .create_deploy_artifact_details import CreateDeployArtifactDetails
from .create_deploy_environment_details import CreateDeployEnvironmentDetails
from .create_deploy_pipeline_deployment_details import CreateDeployPipelineDeploymentDetails
from .create_deploy_pipeline_details import CreateDeployPipelineDetails
from .create_deploy_pipeline_redeployment_details import CreateDeployPipelineRedeploymentDetails
from .create_deploy_stage_details import CreateDeployStageDetails
from .create_deployment_details import CreateDeploymentDetails
from .create_function_deploy_environment_details import CreateFunctionDeployEnvironmentDetails
from .create_function_deploy_stage_details import CreateFunctionDeployStageDetails
from .create_invoke_function_deploy_stage_details import CreateInvokeFunctionDeployStageDetails
from .create_load_balancer_traffic_shift_deploy_stage_details import CreateLoadBalancerTrafficShiftDeployStageDetails
from .create_manual_approval_deploy_stage_details import CreateManualApprovalDeployStageDetails
from .create_oke_cluster_deploy_environment_details import CreateOkeClusterDeployEnvironmentDetails
from .create_oke_deploy_stage_details import CreateOkeDeployStageDetails
from .create_project_details import CreateProjectDetails
from .create_single_deploy_stage_deployment_details import CreateSingleDeployStageDeploymentDetails
from .create_wait_deploy_stage_details import CreateWaitDeployStageDetails
from .deploy_artifact import DeployArtifact
from .deploy_artifact_collection import DeployArtifactCollection
from .deploy_artifact_override_argument import DeployArtifactOverrideArgument
from .deploy_artifact_override_argument_collection import DeployArtifactOverrideArgumentCollection
from .deploy_artifact_source import DeployArtifactSource
from .deploy_artifact_summary import DeployArtifactSummary
from .deploy_environment import DeployEnvironment
from .deploy_environment_collection import DeployEnvironmentCollection
from .deploy_environment_summary import DeployEnvironmentSummary
from .deploy_pipeline import DeployPipeline
from .deploy_pipeline_artifact import DeployPipelineArtifact
from .deploy_pipeline_artifact_collection import DeployPipelineArtifactCollection
from .deploy_pipeline_collection import DeployPipelineCollection
from .deploy_pipeline_deployment import DeployPipelineDeployment
from .deploy_pipeline_deployment_summary import DeployPipelineDeploymentSummary
from .deploy_pipeline_environment import DeployPipelineEnvironment
from .deploy_pipeline_environment_collection import DeployPipelineEnvironmentCollection
from .deploy_pipeline_parameter import DeployPipelineParameter
from .deploy_pipeline_parameter_collection import DeployPipelineParameterCollection
from .deploy_pipeline_redeployment import DeployPipelineRedeployment
from .deploy_pipeline_redeployment_summary import DeployPipelineRedeploymentSummary
from .deploy_pipeline_stage import DeployPipelineStage
from .deploy_pipeline_stage_collection import DeployPipelineStageCollection
from .deploy_pipeline_summary import DeployPipelineSummary
from .deploy_stage import DeployStage
from .deploy_stage_collection import DeployStageCollection
from .deploy_stage_execution_progress import DeployStageExecutionProgress
from .deploy_stage_execution_progress_details import DeployStageExecutionProgressDetails
from .deploy_stage_execution_step import DeployStageExecutionStep
from .deploy_stage_predecessor import DeployStagePredecessor
from .deploy_stage_predecessor_collection import DeployStagePredecessorCollection
from .deploy_stage_rollback_policy import DeployStageRollbackPolicy
from .deploy_stage_summary import DeployStageSummary
from .deployment import Deployment
from .deployment_argument import DeploymentArgument
from .deployment_argument_collection import DeploymentArgumentCollection
from .deployment_collection import DeploymentCollection
from .deployment_execution_progress import DeploymentExecutionProgress
from .deployment_summary import DeploymentSummary
from .function_deploy_environment import FunctionDeployEnvironment
from .function_deploy_environment_summary import FunctionDeployEnvironmentSummary
from .function_deploy_stage import FunctionDeployStage
from .function_deploy_stage_execution_progress import FunctionDeployStageExecutionProgress
from .function_deploy_stage_summary import FunctionDeployStageSummary
from .generic_deploy_artifact_source import GenericDeployArtifactSource
from .inline_deploy_artifact_source import InlineDeployArtifactSource
from .invoke_function_deploy_stage import InvokeFunctionDeployStage
from .invoke_function_deploy_stage_execution_progress import InvokeFunctionDeployStageExecutionProgress
from .invoke_function_deploy_stage_summary import InvokeFunctionDeployStageSummary
from .load_balancer_config import LoadBalancerConfig
from .load_balancer_traffic_shift_deploy_stage import LoadBalancerTrafficShiftDeployStage
from .load_balancer_traffic_shift_deploy_stage_execution_progress import LoadBalancerTrafficShiftDeployStageExecutionProgress
from .load_balancer_traffic_shift_deploy_stage_summary import LoadBalancerTrafficShiftDeployStageSummary
from .load_balancer_traffic_shift_rollout_policy import LoadBalancerTrafficShiftRolloutPolicy
from .manual_approval_deploy_stage import ManualApprovalDeployStage
from .manual_approval_deploy_stage_execution_progress import ManualApprovalDeployStageExecutionProgress
from .manual_approval_deploy_stage_summary import ManualApprovalDeployStageSummary
from .no_deploy_stage_rollback_policy import NoDeployStageRollbackPolicy
from .notification_config import NotificationConfig
from .ocir_deploy_artifact_source import OcirDeployArtifactSource
from .oke_cluster_deploy_environment import OkeClusterDeployEnvironment
from .oke_cluster_deploy_environment_summary import OkeClusterDeployEnvironmentSummary
from .oke_deploy_stage import OkeDeployStage
from .oke_deploy_stage_execution_progress import OkeDeployStageExecutionProgress
from .oke_deploy_stage_summary import OkeDeployStageSummary
from .project import Project
from .project_collection import ProjectCollection
from .project_summary import ProjectSummary
from .run_pipeline_deploy_stage_execution_progress import RunPipelineDeployStageExecutionProgress
from .run_validation_test_on_compute_instance_deploy_stage_execution_progress import RunValidationTestOnComputeInstanceDeployStageExecutionProgress
from .single_deploy_stage_deployment import SingleDeployStageDeployment
from .single_deploy_stage_deployment_summary import SingleDeployStageDeploymentSummary
from .update_compute_instance_group_deploy_environment_details import UpdateComputeInstanceGroupDeployEnvironmentDetails
from .update_compute_instance_group_deploy_stage_details import UpdateComputeInstanceGroupDeployStageDetails
from .update_deploy_artifact_details import UpdateDeployArtifactDetails
from .update_deploy_environment_details import UpdateDeployEnvironmentDetails
from .update_deploy_pipeline_deployment_details import UpdateDeployPipelineDeploymentDetails
from .update_deploy_pipeline_details import UpdateDeployPipelineDetails
from .update_deploy_pipeline_redeployment_details import UpdateDeployPipelineRedeploymentDetails
from .update_deploy_stage_details import UpdateDeployStageDetails
from .update_deployment_details import UpdateDeploymentDetails
from .update_function_deploy_environment_details import UpdateFunctionDeployEnvironmentDetails
from .update_function_deploy_stage_details import UpdateFunctionDeployStageDetails
from .update_invoke_function_deploy_stage_details import UpdateInvokeFunctionDeployStageDetails
from .update_load_balancer_traffic_shift_deploy_stage_details import UpdateLoadBalancerTrafficShiftDeployStageDetails
from .update_manual_approval_deploy_stage_details import UpdateManualApprovalDeployStageDetails
from .update_oke_cluster_deploy_environment_details import UpdateOkeClusterDeployEnvironmentDetails
from .update_oke_deploy_stage_details import UpdateOkeDeployStageDetails
from .update_project_details import UpdateProjectDetails
from .update_single_deploy_stage_deployment_details import UpdateSingleDeployStageDeploymentDetails
from .update_wait_deploy_stage_details import UpdateWaitDeployStageDetails
from .wait_criteria import WaitCriteria
from .wait_criteria_summary import WaitCriteriaSummary
from .wait_deploy_stage import WaitDeployStage
from .wait_deploy_stage_execution_progress import WaitDeployStageExecutionProgress
from .wait_deploy_stage_summary import WaitDeployStageSummary
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for devops services.
devops_type_mapping = {
    "AbsoluteWaitCriteria": AbsoluteWaitCriteria,
    "AbsoluteWaitCriteriaSummary": AbsoluteWaitCriteriaSummary,
    "ApprovalAction": ApprovalAction,
    "ApprovalPolicy": ApprovalPolicy,
    "ApproveDeploymentDetails": ApproveDeploymentDetails,
    "AutomatedDeployStageRollbackPolicy": AutomatedDeployStageRollbackPolicy,
    "BackendSetIpCollection": BackendSetIpCollection,
    "CancelDeploymentDetails": CancelDeploymentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "ComputeInstanceGroupBlueGreenDeployStageExecutionProgress": ComputeInstanceGroupBlueGreenDeployStageExecutionProgress,
    "ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress": ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress,
    "ComputeInstanceGroupByIdsSelector": ComputeInstanceGroupByIdsSelector,
    "ComputeInstanceGroupByQuerySelector": ComputeInstanceGroupByQuerySelector,
    "ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress": ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress,
    "ComputeInstanceGroupCanaryDeployStageExecutionProgress": ComputeInstanceGroupCanaryDeployStageExecutionProgress,
    "ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress": ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress,
    "ComputeInstanceGroupDeployEnvironment": ComputeInstanceGroupDeployEnvironment,
    "ComputeInstanceGroupDeployEnvironmentSummary": ComputeInstanceGroupDeployEnvironmentSummary,
    "ComputeInstanceGroupDeployStage": ComputeInstanceGroupDeployStage,
    "ComputeInstanceGroupDeployStageExecutionProgress": ComputeInstanceGroupDeployStageExecutionProgress,
    "ComputeInstanceGroupDeployStageSummary": ComputeInstanceGroupDeployStageSummary,
    "ComputeInstanceGroupFailurePolicy": ComputeInstanceGroupFailurePolicy,
    "ComputeInstanceGroupFailurePolicyByCount": ComputeInstanceGroupFailurePolicyByCount,
    "ComputeInstanceGroupFailurePolicyByPercentage": ComputeInstanceGroupFailurePolicyByPercentage,
    "ComputeInstanceGroupLinearRolloutPolicyByCount": ComputeInstanceGroupLinearRolloutPolicyByCount,
    "ComputeInstanceGroupLinearRolloutPolicyByPercentage": ComputeInstanceGroupLinearRolloutPolicyByPercentage,
    "ComputeInstanceGroupRolloutPolicy": ComputeInstanceGroupRolloutPolicy,
    "ComputeInstanceGroupSelector": ComputeInstanceGroupSelector,
    "ComputeInstanceGroupSelectorCollection": ComputeInstanceGroupSelectorCollection,
    "CountBasedApprovalPolicy": CountBasedApprovalPolicy,
    "CreateComputeInstanceGroupDeployEnvironmentDetails": CreateComputeInstanceGroupDeployEnvironmentDetails,
    "CreateComputeInstanceGroupDeployStageDetails": CreateComputeInstanceGroupDeployStageDetails,
    "CreateDeployArtifactDetails": CreateDeployArtifactDetails,
    "CreateDeployEnvironmentDetails": CreateDeployEnvironmentDetails,
    "CreateDeployPipelineDeploymentDetails": CreateDeployPipelineDeploymentDetails,
    "CreateDeployPipelineDetails": CreateDeployPipelineDetails,
    "CreateDeployPipelineRedeploymentDetails": CreateDeployPipelineRedeploymentDetails,
    "CreateDeployStageDetails": CreateDeployStageDetails,
    "CreateDeploymentDetails": CreateDeploymentDetails,
    "CreateFunctionDeployEnvironmentDetails": CreateFunctionDeployEnvironmentDetails,
    "CreateFunctionDeployStageDetails": CreateFunctionDeployStageDetails,
    "CreateInvokeFunctionDeployStageDetails": CreateInvokeFunctionDeployStageDetails,
    "CreateLoadBalancerTrafficShiftDeployStageDetails": CreateLoadBalancerTrafficShiftDeployStageDetails,
    "CreateManualApprovalDeployStageDetails": CreateManualApprovalDeployStageDetails,
    "CreateOkeClusterDeployEnvironmentDetails": CreateOkeClusterDeployEnvironmentDetails,
    "CreateOkeDeployStageDetails": CreateOkeDeployStageDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "CreateSingleDeployStageDeploymentDetails": CreateSingleDeployStageDeploymentDetails,
    "CreateWaitDeployStageDetails": CreateWaitDeployStageDetails,
    "DeployArtifact": DeployArtifact,
    "DeployArtifactCollection": DeployArtifactCollection,
    "DeployArtifactOverrideArgument": DeployArtifactOverrideArgument,
    "DeployArtifactOverrideArgumentCollection": DeployArtifactOverrideArgumentCollection,
    "DeployArtifactSource": DeployArtifactSource,
    "DeployArtifactSummary": DeployArtifactSummary,
    "DeployEnvironment": DeployEnvironment,
    "DeployEnvironmentCollection": DeployEnvironmentCollection,
    "DeployEnvironmentSummary": DeployEnvironmentSummary,
    "DeployPipeline": DeployPipeline,
    "DeployPipelineArtifact": DeployPipelineArtifact,
    "DeployPipelineArtifactCollection": DeployPipelineArtifactCollection,
    "DeployPipelineCollection": DeployPipelineCollection,
    "DeployPipelineDeployment": DeployPipelineDeployment,
    "DeployPipelineDeploymentSummary": DeployPipelineDeploymentSummary,
    "DeployPipelineEnvironment": DeployPipelineEnvironment,
    "DeployPipelineEnvironmentCollection": DeployPipelineEnvironmentCollection,
    "DeployPipelineParameter": DeployPipelineParameter,
    "DeployPipelineParameterCollection": DeployPipelineParameterCollection,
    "DeployPipelineRedeployment": DeployPipelineRedeployment,
    "DeployPipelineRedeploymentSummary": DeployPipelineRedeploymentSummary,
    "DeployPipelineStage": DeployPipelineStage,
    "DeployPipelineStageCollection": DeployPipelineStageCollection,
    "DeployPipelineSummary": DeployPipelineSummary,
    "DeployStage": DeployStage,
    "DeployStageCollection": DeployStageCollection,
    "DeployStageExecutionProgress": DeployStageExecutionProgress,
    "DeployStageExecutionProgressDetails": DeployStageExecutionProgressDetails,
    "DeployStageExecutionStep": DeployStageExecutionStep,
    "DeployStagePredecessor": DeployStagePredecessor,
    "DeployStagePredecessorCollection": DeployStagePredecessorCollection,
    "DeployStageRollbackPolicy": DeployStageRollbackPolicy,
    "DeployStageSummary": DeployStageSummary,
    "Deployment": Deployment,
    "DeploymentArgument": DeploymentArgument,
    "DeploymentArgumentCollection": DeploymentArgumentCollection,
    "DeploymentCollection": DeploymentCollection,
    "DeploymentExecutionProgress": DeploymentExecutionProgress,
    "DeploymentSummary": DeploymentSummary,
    "FunctionDeployEnvironment": FunctionDeployEnvironment,
    "FunctionDeployEnvironmentSummary": FunctionDeployEnvironmentSummary,
    "FunctionDeployStage": FunctionDeployStage,
    "FunctionDeployStageExecutionProgress": FunctionDeployStageExecutionProgress,
    "FunctionDeployStageSummary": FunctionDeployStageSummary,
    "GenericDeployArtifactSource": GenericDeployArtifactSource,
    "InlineDeployArtifactSource": InlineDeployArtifactSource,
    "InvokeFunctionDeployStage": InvokeFunctionDeployStage,
    "InvokeFunctionDeployStageExecutionProgress": InvokeFunctionDeployStageExecutionProgress,
    "InvokeFunctionDeployStageSummary": InvokeFunctionDeployStageSummary,
    "LoadBalancerConfig": LoadBalancerConfig,
    "LoadBalancerTrafficShiftDeployStage": LoadBalancerTrafficShiftDeployStage,
    "LoadBalancerTrafficShiftDeployStageExecutionProgress": LoadBalancerTrafficShiftDeployStageExecutionProgress,
    "LoadBalancerTrafficShiftDeployStageSummary": LoadBalancerTrafficShiftDeployStageSummary,
    "LoadBalancerTrafficShiftRolloutPolicy": LoadBalancerTrafficShiftRolloutPolicy,
    "ManualApprovalDeployStage": ManualApprovalDeployStage,
    "ManualApprovalDeployStageExecutionProgress": ManualApprovalDeployStageExecutionProgress,
    "ManualApprovalDeployStageSummary": ManualApprovalDeployStageSummary,
    "NoDeployStageRollbackPolicy": NoDeployStageRollbackPolicy,
    "NotificationConfig": NotificationConfig,
    "OcirDeployArtifactSource": OcirDeployArtifactSource,
    "OkeClusterDeployEnvironment": OkeClusterDeployEnvironment,
    "OkeClusterDeployEnvironmentSummary": OkeClusterDeployEnvironmentSummary,
    "OkeDeployStage": OkeDeployStage,
    "OkeDeployStageExecutionProgress": OkeDeployStageExecutionProgress,
    "OkeDeployStageSummary": OkeDeployStageSummary,
    "Project": Project,
    "ProjectCollection": ProjectCollection,
    "ProjectSummary": ProjectSummary,
    "RunPipelineDeployStageExecutionProgress": RunPipelineDeployStageExecutionProgress,
    "RunValidationTestOnComputeInstanceDeployStageExecutionProgress": RunValidationTestOnComputeInstanceDeployStageExecutionProgress,
    "SingleDeployStageDeployment": SingleDeployStageDeployment,
    "SingleDeployStageDeploymentSummary": SingleDeployStageDeploymentSummary,
    "UpdateComputeInstanceGroupDeployEnvironmentDetails": UpdateComputeInstanceGroupDeployEnvironmentDetails,
    "UpdateComputeInstanceGroupDeployStageDetails": UpdateComputeInstanceGroupDeployStageDetails,
    "UpdateDeployArtifactDetails": UpdateDeployArtifactDetails,
    "UpdateDeployEnvironmentDetails": UpdateDeployEnvironmentDetails,
    "UpdateDeployPipelineDeploymentDetails": UpdateDeployPipelineDeploymentDetails,
    "UpdateDeployPipelineDetails": UpdateDeployPipelineDetails,
    "UpdateDeployPipelineRedeploymentDetails": UpdateDeployPipelineRedeploymentDetails,
    "UpdateDeployStageDetails": UpdateDeployStageDetails,
    "UpdateDeploymentDetails": UpdateDeploymentDetails,
    "UpdateFunctionDeployEnvironmentDetails": UpdateFunctionDeployEnvironmentDetails,
    "UpdateFunctionDeployStageDetails": UpdateFunctionDeployStageDetails,
    "UpdateInvokeFunctionDeployStageDetails": UpdateInvokeFunctionDeployStageDetails,
    "UpdateLoadBalancerTrafficShiftDeployStageDetails": UpdateLoadBalancerTrafficShiftDeployStageDetails,
    "UpdateManualApprovalDeployStageDetails": UpdateManualApprovalDeployStageDetails,
    "UpdateOkeClusterDeployEnvironmentDetails": UpdateOkeClusterDeployEnvironmentDetails,
    "UpdateOkeDeployStageDetails": UpdateOkeDeployStageDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "UpdateSingleDeployStageDeploymentDetails": UpdateSingleDeployStageDeploymentDetails,
    "UpdateWaitDeployStageDetails": UpdateWaitDeployStageDetails,
    "WaitCriteria": WaitCriteria,
    "WaitCriteriaSummary": WaitCriteriaSummary,
    "WaitDeployStage": WaitDeployStage,
    "WaitDeployStageExecutionProgress": WaitDeployStageExecutionProgress,
    "WaitDeployStageSummary": WaitDeployStageSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlPlanInsightAggregation(object):
    """
    SQL execution plan Performance statistics.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlPlanInsightAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param plan_hash:
            The value to assign to the plan_hash property of this SqlPlanInsightAggregation.
        :type plan_hash: int

        :param io_time_in_sec:
            The value to assign to the io_time_in_sec property of this SqlPlanInsightAggregation.
        :type io_time_in_sec: float

        :param cpu_time_in_sec:
            The value to assign to the cpu_time_in_sec property of this SqlPlanInsightAggregation.
        :type cpu_time_in_sec: float

        :param inefficient_wait_time_in_sec:
            The value to assign to the inefficient_wait_time_in_sec property of this SqlPlanInsightAggregation.
        :type inefficient_wait_time_in_sec: float

        :param executions_count:
            The value to assign to the executions_count property of this SqlPlanInsightAggregation.
        :type executions_count: int

        """
        self.swagger_types = {
            'plan_hash': 'int',
            'io_time_in_sec': 'float',
            'cpu_time_in_sec': 'float',
            'inefficient_wait_time_in_sec': 'float',
            'executions_count': 'int'
        }

        self.attribute_map = {
            'plan_hash': 'planHash',
            'io_time_in_sec': 'ioTimeInSec',
            'cpu_time_in_sec': 'cpuTimeInSec',
            'inefficient_wait_time_in_sec': 'inefficientWaitTimeInSec',
            'executions_count': 'executionsCount'
        }

        self._plan_hash = None
        self._io_time_in_sec = None
        self._cpu_time_in_sec = None
        self._inefficient_wait_time_in_sec = None
        self._executions_count = None

    @property
    def plan_hash(self):
        """
        **[Required]** Gets the plan_hash of this SqlPlanInsightAggregation.
        Plan hash value for the SQL Execution Plan


        :return: The plan_hash of this SqlPlanInsightAggregation.
        :rtype: int
        """
        return self._plan_hash

    @plan_hash.setter
    def plan_hash(self, plan_hash):
        """
        Sets the plan_hash of this SqlPlanInsightAggregation.
        Plan hash value for the SQL Execution Plan


        :param plan_hash: The plan_hash of this SqlPlanInsightAggregation.
        :type: int
        """
        self._plan_hash = plan_hash

    @property
    def io_time_in_sec(self):
        """
        **[Required]** Gets the io_time_in_sec of this SqlPlanInsightAggregation.
        IO Time in seconds


        :return: The io_time_in_sec of this SqlPlanInsightAggregation.
        :rtype: float
        """
        return self._io_time_in_sec

    @io_time_in_sec.setter
    def io_time_in_sec(self, io_time_in_sec):
        """
        Sets the io_time_in_sec of this SqlPlanInsightAggregation.
        IO Time in seconds


        :param io_time_in_sec: The io_time_in_sec of this SqlPlanInsightAggregation.
        :type: float
        """
        self._io_time_in_sec = io_time_in_sec

    @property
    def cpu_time_in_sec(self):
        """
        **[Required]** Gets the cpu_time_in_sec of this SqlPlanInsightAggregation.
        CPU Time in seconds


        :return: The cpu_time_in_sec of this SqlPlanInsightAggregation.
        :rtype: float
        """
        return self._cpu_time_in_sec

    @cpu_time_in_sec.setter
    def cpu_time_in_sec(self, cpu_time_in_sec):
        """
        Sets the cpu_time_in_sec of this SqlPlanInsightAggregation.
        CPU Time in seconds


        :param cpu_time_in_sec: The cpu_time_in_sec of this SqlPlanInsightAggregation.
        :type: float
        """
        self._cpu_time_in_sec = cpu_time_in_sec

    @property
    def inefficient_wait_time_in_sec(self):
        """
        **[Required]** Gets the inefficient_wait_time_in_sec of this SqlPlanInsightAggregation.
        Inefficient Wait Time in seconds


        :return: The inefficient_wait_time_in_sec of this SqlPlanInsightAggregation.
        :rtype: float
        """
        return self._inefficient_wait_time_in_sec

    @inefficient_wait_time_in_sec.setter
    def inefficient_wait_time_in_sec(self, inefficient_wait_time_in_sec):
        """
        Sets the inefficient_wait_time_in_sec of this SqlPlanInsightAggregation.
        Inefficient Wait Time in seconds


        :param inefficient_wait_time_in_sec: The inefficient_wait_time_in_sec of this SqlPlanInsightAggregation.
        :type: float
        """
        self._inefficient_wait_time_in_sec = inefficient_wait_time_in_sec

    @property
    def executions_count(self):
        """
        **[Required]** Gets the executions_count of this SqlPlanInsightAggregation.
        Total number of executions


        :return: The executions_count of this SqlPlanInsightAggregation.
        :rtype: int
        """
        return self._executions_count

    @executions_count.setter
    def executions_count(self, executions_count):
        """
        Sets the executions_count of this SqlPlanInsightAggregation.
        Total number of executions


        :param executions_count: The executions_count of this SqlPlanInsightAggregation.
        :type: int
        """
        self._executions_count = executions_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseDetails(object):
    """
    Details of the database for the registration in Data Safe.
    To choose applicable database type and infrastructure type refer to
    https://confluence.oci.oraclecorp.com/display/DATASAFE/Target+V2+Design
    """

    #: A constant which can be used with the database_type property of a DatabaseDetails.
    #: This constant has a value of "DATABASE_CLOUD_SERVICE"
    DATABASE_TYPE_DATABASE_CLOUD_SERVICE = "DATABASE_CLOUD_SERVICE"

    #: A constant which can be used with the database_type property of a DatabaseDetails.
    #: This constant has a value of "AUTONOMOUS_DATABASE"
    DATABASE_TYPE_AUTONOMOUS_DATABASE = "AUTONOMOUS_DATABASE"

    #: A constant which can be used with the database_type property of a DatabaseDetails.
    #: This constant has a value of "INSTALLED_DATABASE"
    DATABASE_TYPE_INSTALLED_DATABASE = "INSTALLED_DATABASE"

    #: A constant which can be used with the infrastructure_type property of a DatabaseDetails.
    #: This constant has a value of "ORACLE_CLOUD"
    INFRASTRUCTURE_TYPE_ORACLE_CLOUD = "ORACLE_CLOUD"

    #: A constant which can be used with the infrastructure_type property of a DatabaseDetails.
    #: This constant has a value of "CLOUD_AT_CUSTOMER"
    INFRASTRUCTURE_TYPE_CLOUD_AT_CUSTOMER = "CLOUD_AT_CUSTOMER"

    #: A constant which can be used with the infrastructure_type property of a DatabaseDetails.
    #: This constant has a value of "ON_PREMISES"
    INFRASTRUCTURE_TYPE_ON_PREMISES = "ON_PREMISES"

    #: A constant which can be used with the infrastructure_type property of a DatabaseDetails.
    #: This constant has a value of "NON_ORACLE_CLOUD"
    INFRASTRUCTURE_TYPE_NON_ORACLE_CLOUD = "NON_ORACLE_CLOUD"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_safe.models.InstalledDatabaseDetails`
        * :class:`~oci.data_safe.models.AutonomousDatabaseDetails`
        * :class:`~oci.data_safe.models.DatabaseCloudServiceDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_type:
            The value to assign to the database_type property of this DatabaseDetails.
            Allowed values for this property are: "DATABASE_CLOUD_SERVICE", "AUTONOMOUS_DATABASE", "INSTALLED_DATABASE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_type: str

        :param infrastructure_type:
            The value to assign to the infrastructure_type property of this DatabaseDetails.
            Allowed values for this property are: "ORACLE_CLOUD", "CLOUD_AT_CUSTOMER", "ON_PREMISES", "NON_ORACLE_CLOUD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type infrastructure_type: str

        """
        self.swagger_types = {
            'database_type': 'str',
            'infrastructure_type': 'str'
        }

        self.attribute_map = {
            'database_type': 'databaseType',
            'infrastructure_type': 'infrastructureType'
        }

        self._database_type = None
        self._infrastructure_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['databaseType']

        if type == 'INSTALLED_DATABASE':
            return 'InstalledDatabaseDetails'

        if type == 'AUTONOMOUS_DATABASE':
            return 'AutonomousDatabaseDetails'

        if type == 'DATABASE_CLOUD_SERVICE':
            return 'DatabaseCloudServiceDetails'
        else:
            return 'DatabaseDetails'

    @property
    def database_type(self):
        """
        **[Required]** Gets the database_type of this DatabaseDetails.
        The database type.

        Allowed values for this property are: "DATABASE_CLOUD_SERVICE", "AUTONOMOUS_DATABASE", "INSTALLED_DATABASE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_type of this DatabaseDetails.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this DatabaseDetails.
        The database type.


        :param database_type: The database_type of this DatabaseDetails.
        :type: str
        """
        allowed_values = ["DATABASE_CLOUD_SERVICE", "AUTONOMOUS_DATABASE", "INSTALLED_DATABASE"]
        if not value_allowed_none_or_none_sentinel(database_type, allowed_values):
            database_type = 'UNKNOWN_ENUM_VALUE'
        self._database_type = database_type

    @property
    def infrastructure_type(self):
        """
        **[Required]** Gets the infrastructure_type of this DatabaseDetails.
        The infrastructure type the database is running on.

        Allowed values for this property are: "ORACLE_CLOUD", "CLOUD_AT_CUSTOMER", "ON_PREMISES", "NON_ORACLE_CLOUD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The infrastructure_type of this DatabaseDetails.
        :rtype: str
        """
        return self._infrastructure_type

    @infrastructure_type.setter
    def infrastructure_type(self, infrastructure_type):
        """
        Sets the infrastructure_type of this DatabaseDetails.
        The infrastructure type the database is running on.


        :param infrastructure_type: The infrastructure_type of this DatabaseDetails.
        :type: str
        """
        allowed_values = ["ORACLE_CLOUD", "CLOUD_AT_CUSTOMER", "ON_PREMISES", "NON_ORACLE_CLOUD"]
        if not value_allowed_none_or_none_sentinel(infrastructure_type, allowed_values):
            infrastructure_type = 'UNKNOWN_ENUM_VALUE'
        self._infrastructure_type = infrastructure_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestResourceSubTypeDetail(object):
    """
    SubType information for a work request resource.
    """

    #: A constant which can be used with the sub_type_status property of a WorkRequestResourceSubTypeDetail.
    #: This constant has a value of "CREATED"
    SUB_TYPE_STATUS_CREATED = "CREATED"

    #: A constant which can be used with the sub_type_status property of a WorkRequestResourceSubTypeDetail.
    #: This constant has a value of "UPDATED"
    SUB_TYPE_STATUS_UPDATED = "UPDATED"

    #: A constant which can be used with the sub_type_status property of a WorkRequestResourceSubTypeDetail.
    #: This constant has a value of "DELETED"
    SUB_TYPE_STATUS_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestResourceSubTypeDetail object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sub_type:
            The value to assign to the sub_type property of this WorkRequestResourceSubTypeDetail.
        :type sub_type: str

        :param sub_type_key:
            The value to assign to the sub_type_key property of this WorkRequestResourceSubTypeDetail.
        :type sub_type_key: str

        :param sub_type_status:
            The value to assign to the sub_type_status property of this WorkRequestResourceSubTypeDetail.
            Allowed values for this property are: "CREATED", "UPDATED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type sub_type_status: str

        """
        self.swagger_types = {
            'sub_type': 'str',
            'sub_type_key': 'str',
            'sub_type_status': 'str'
        }

        self.attribute_map = {
            'sub_type': 'subType',
            'sub_type_key': 'subTypeKey',
            'sub_type_status': 'subTypeStatus'
        }

        self._sub_type = None
        self._sub_type_key = None
        self._sub_type_status = None

    @property
    def sub_type(self):
        """
        **[Required]** Gets the sub_type of this WorkRequestResourceSubTypeDetail.
        Subtype of the work request resource like osn or peer.


        :return: The sub_type of this WorkRequestResourceSubTypeDetail.
        :rtype: str
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """
        Sets the sub_type of this WorkRequestResourceSubTypeDetail.
        Subtype of the work request resource like osn or peer.


        :param sub_type: The sub_type of this WorkRequestResourceSubTypeDetail.
        :type: str
        """
        self._sub_type = sub_type

    @property
    def sub_type_key(self):
        """
        **[Required]** Gets the sub_type_key of this WorkRequestResourceSubTypeDetail.
        The identifier of the resource subType.


        :return: The sub_type_key of this WorkRequestResourceSubTypeDetail.
        :rtype: str
        """
        return self._sub_type_key

    @sub_type_key.setter
    def sub_type_key(self, sub_type_key):
        """
        Sets the sub_type_key of this WorkRequestResourceSubTypeDetail.
        The identifier of the resource subType.


        :param sub_type_key: The sub_type_key of this WorkRequestResourceSubTypeDetail.
        :type: str
        """
        self._sub_type_key = sub_type_key

    @property
    def sub_type_status(self):
        """
        **[Required]** Gets the sub_type_status of this WorkRequestResourceSubTypeDetail.
        Status of the resource subType, as a result of the work tracked in this work request.
        A resource subType would be CREATED, UPDATED or DELETED, after the work request is completed.

        Allowed values for this property are: "CREATED", "UPDATED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The sub_type_status of this WorkRequestResourceSubTypeDetail.
        :rtype: str
        """
        return self._sub_type_status

    @sub_type_status.setter
    def sub_type_status(self, sub_type_status):
        """
        Sets the sub_type_status of this WorkRequestResourceSubTypeDetail.
        Status of the resource subType, as a result of the work tracked in this work request.
        A resource subType would be CREATED, UPDATED or DELETED, after the work request is completed.


        :param sub_type_status: The sub_type_status of this WorkRequestResourceSubTypeDetail.
        :type: str
        """
        allowed_values = ["CREATED", "UPDATED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(sub_type_status, allowed_values):
            sub_type_status = 'UNKNOWN_ENUM_VALUE'
        self._sub_type_status = sub_type_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
